#################################################
#
#  (C) 2010-2011 Serghei Amelian
#  serghei (DOT) amelian (AT) gmail.com
#
#  Improvements and feedback are welcome
#
#  This file is released under GPL >= 2
#
#################################################


include( CheckIncludeFileCXX )
if( BUILD_KAMERA )
  pkg_search_module( GPHOTO2 libgphoto2 )
  if( NOT GPHOTO2_FOUND )
    tde_message_fatal( "libgphoto2 is required, but was not found on your system" )
  endif( )
endif( )


if( BUILD_LIBKSCAN ) 
  check_library_exists(  sane sane_init "" HAVE_SANE )
  if( HAVE_SANE )
    check_include_file( "sane/sane.h" HAVE_SANE_H )
  endif( )
  if(HAVE_SANE AND HAVE_SANE_H )  
  set( SANE_LIBRARY sane CACHE INTERNAL "" FORCE )
  else( )
    tde_message_fatal( "sane is required, but was not found on your system" ) 
  endif( )
endif( ) 

if( BUILD_KFILEPLUGINS)
  pkg_search_module( OPENEXR OpenEXR )
  if( NOT OPENEXR_FOUND )
    tde_message_fatal("openexr is required, but was not found on your system" )
  endif( )

  pkg_search_module( POPPLERQT poppler-qt )
  if( NOT POPPLERQT_FOUND )
    tde_message_fatal("Poppler-Qt3 bindings are required, but were not found on your system" )
  endif( )
  
  check_library_exists(  tiff TIFFOpen "" HAVE_TIFF )
  if( HAVE_TIFF )
    check_include_file( "tiff.h" HAVE_TIFF_H )
  endif( )
  if(HAVE_TIFF AND HAVE_TIFF_H )  
    set( TIFF_LIBRARY tiff CACHE INTERNAL "" FORCE )
  else( )
    tde_message_fatal( "tiff is required, but was not found on your system" ) 
  endif( )
endif( )

if( BUILD_KGAMMA ) 
  check_library_exists( Xxf86vm XF86VidModeSetGammaRamp "" HAVE_XF86VMODE )
  if( HAVE_XF86VMODE )
    tde_save( CMAKE_REQUIRED_FLAGS )
    set( CMAKE_REQUIRED_FLAGS "-include X11/Xlib.h -include X11/Xatom.h" )
    check_include_file( "X11/extensions/xf86vmode.h" HAVE_XF86VMODE_H )
    tde_restore( CMAKE_REQUIRED_FLAGS )
  endif( )
  if(HAVE_XF86VMODE AND HAVE_XF86VMODE_H )  
  set( XF86VMODE_H Xxf86vm CACHE INTERNAL "" FORCE )
  else( )
    tde_message_fatal( "X11 - xf86vmode is required, but was not found on your system" ) 
  endif( )
  CHECK_INCLUDE_FILE_CXX("sstream" HAVE_SSTREAM )
  if( HAVE_SSTREAM )
    set( HAVE_SSTREAM TRUE )
  else( )
    tde_message_fatal( "sstream is required, but was not found on your system." )
  endif( )
endif( )

if( BUILD_KVIEWSHELL )
  set( UNIX TRUE )
endif( )

if( BUILD_KUICKSHOW )
  pkg_search_module( IMLIB imlib )
    if( NOT IMLIB_FOUND )
    tde_message_fatal("imlib is required, but was not found on your system" )
  endif( )
endif( )

if( BUILD_KPOVMODELER )
  pkg_search_module( GLU glu )
  if( NOT GLU_FOUND )
    tde_message_fatal("glu (OpenGL utility library) is required, but was not found on your system" )
  endif( )
  pkg_search_module( FREETYPE freetype2)
    if( FREETYPE_FOUND )
      set( HAVE_FREETYPE TRUE )
    else( )
      tde_message_fatal("freetype is required, but was not found on your system")
    endif( )
endif( )

if( BUILD_KDVI )
  check_include_file_cxx("stdlib.h" HAVE_STDLIB_H)
  if( HAVE_STDLIB_H )
    set ( HAVE_STDLIB_H TRUE )
  else( ) 
    tde_message_fatal("stdlib.h is required, but was not found on your system")
  endif( )
  
  pkg_search_module( FREETYPE freetype2)
  if( FREETYPE_FOUND )
    set( HAVE_FREETYPE TRUE )
  else( )
    tde_message_fatal("freetype is required, but was not found on your system")
  endif( )
endif( )

#if( BUILD_KPDF )
#  pkg_search_module( FREETYPE freetype2)
#  if( FREETYPE_FOUND )
#    set( HAVE_FREETYPE TRUE )
#  else( )
#    tde_message_fatal("freetype is required, but was not found on your system")
#  endif( )
#  pkg_search_module( XFT xft )
#  if( XFT_FOUND )
#    set( HAVE_XFT TRUE )
#  else( )
#    tde_message_fatal("freetype is required, but was not found on your system")
#  endif( )
#endif()

# required stuff
find_package( Qt )
find_package( TQt )
find_package( TDE )
